[**Advanced**](./introduction.md) > **Language Code** _(current)_

---

#### Google

Source <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organized by GPT-4o.

| Label in Chinese | Label | `Language Code` |
| --- | --- | --- |
| 阿姆哈拉语 | Amharic | `am` |
| 阿拉伯语 | Arabic | `ar` |
| 巴斯克语 | Basque | `eu` |
| 孟加拉语 | Bengali | `bn` |
| 英语（英国） | English (UK) | `en-GB` |
| 葡萄牙语（巴西） | Portuguese (Brazil) | `pt-BR` |
| 保加利亚语 | Bulgarian | `bg` |
| 加泰罗尼亚语 | Catalan | `ca` |
| 切罗基语 | Cherokee | `chr` |
| 克罗地亚语 | Croatian | `hr` |
| 捷克语 | Czech | `cs` |
| 丹麦语 | Danish | `da` |
| 荷兰语 | Dutch | `nl` |
| 英语（美国） | English (US) | `en` |
| 爱沙尼亚语 | Estonian | `et` |
| 菲律宾语 | Filipino | `fil` |
| 芬兰语 | Finnish | `fi` |
| 法语 | French | `fr` |
| 德语 | German | `de` |
| 希腊语 | Greek | `el` |
| 古吉拉特语 | Gujarati | `gu` |
| 希伯来语 | Hebrew | `iw` |
| 印地语 | Hindi | `hi` |
| 匈牙利语 | Hungarian | `hu` |
| 冰岛语 | Icelandic | `is` |
| 印度尼西亚语 | Indonesian | `id` |
| 意大利语 | Italian | `it` |
| 日语 | Japanese | `ja` |
| 卡纳达语 | Kannada | `kn` |
| 韩语 | Korean | `ko` |
| 拉脱维亚语 | Latvian | `lv` |
| 立陶宛语 | Lithuanian | `lt` |
| 马来语 | Malay | `ms` |
| 马拉雅拉姆语 | Malayalam | `ml` |
| 马拉地语 | Marathi | `mr` |
| 挪威语 | Norwegian | `no` |
| 波兰语 | Polish | `pl` |
| 葡萄牙语（葡萄牙） | Portuguese (Portugal) | `pt-PT` |
| 罗马尼亚语 | Romanian | `ro` |
| 俄语 | Russian | `ru` |
| 塞尔维亚语 | Serbian | `sr` |
| 中文（中国） | Chinese (PRC) | `zh-CN` |
| 斯洛伐克语 | Slovak | `sk` |
| 斯洛文尼亚语 | Slovenian | `sl` |
| 西班牙语 | Spanish | `es` |
| 斯瓦希里语 | Swahili | `sw` |
| 瑞典语 | Swedish | `sv` |
| 泰米尔语 | Tamil | `ta` |
| 泰卢固语 | Telugu | `te` |
| 泰语 | Thai | `th` |
| 中文（台湾） | Chinese (Taiwan) | `zh-TW` |
| 土耳其语 | Turkish | `tr` |
| 乌尔都语 | Urdu | `ur` |
| 乌克兰语 | Ukrainian | `uk` |
| 越南语 | Vietnamese | `vi` |
| 威尔士语 | Welsh | `cy` |


#### DeepL
Source <https://developers.deepl.com/docs/resources/supported-languages>, organized by GPT-4o.

| Label in Chinese | Label | `Language Code`| Supports |
| --- | --- | --- | --- |
| 阿拉伯语 | Arabic | `AR` | `source`, `target` |
| 保加利亚语 | Bulgarian | `BG` | `source`, `target` |
| 捷克语 | Czech | `CS` | `source`, `target` |
| 丹麦语 | Danish | `DA` | `source`, `target` |
| 德语 | German | `DE` | `source`, `target` |
| 希腊语 | Greek | `EL` | `source`, `target` |
| 英语 | English | `EN` | `source`, `target` |
| 英语（英国） | English (British) | `EN-GB` | `target` |
| 英语（美国） | English (American) | `EN-US` | `target` |
| 西班牙语 | Spanish | `ES` | `source`, `target` |
| 爱沙尼亚语 | Estonian | `ET` | `source`, `target` |
| 芬兰语 | Finnish | `FI` | `source`, `target` |
| 法语 | French | `FR` | `source`, `target` |
| 匈牙利语 | Hungarian | `HU` | `source`, `target` |
| 印度尼西亚语 | Indonesian | `ID` | `source`, `target` |
| 意大利语 | Italian | `IT` | `source`, `target` |
| 日语 | Japanese | `JA` | `source`, `target` |
| 韩语 | Korean | `KO` | `source`, `target` |
| 立陶宛语 | Lithuanian | `LT` | `source`, `target` |
| 拉脱维亚语 | Latvian | `LV` | `source`, `target` |
| 挪威博克马尔语 | Norwegian Bokmål | `NB` | `source`, `target` |
| 荷兰语 | Dutch | `NL` | `source`, `target` |
| 波兰语 | Polish | `PL` | `source`, `target` |
| 葡萄牙语 | Portuguese | `PT` | `source`, `target` |
| 葡萄牙语（巴西） | Portuguese (Brazilian) | `PT-BR` | `target` |
| 葡萄牙语（欧洲） | Portuguese (European) | `PT-PT` | `target` |
| 罗马尼亚语 | Romanian | `RO` | `source`, `target` |
| 俄语 | Russian | `RU` | `source`, `target` |
| 斯洛伐克语 | Slovak | `SK` | `source`, `target` |
| 斯洛文尼亚语 | Slovenian | `SL` | `source`, `target` |
| 瑞典语 | Swedish | `SV` | `source`, `target` |
| 土耳其语 | Turkish | `TR` | `source`, `target` |
| 乌克兰语 | Ukrainian | `UK` | `source`, `target` |
| 中文 | Chinese | `ZH` | `source`, `target` |
| 中文（简体） | Chinese (Simplified) | `ZH-HANS` | `target` |
| 中文（繁体） | Chinese (Traditional) | `ZH-HANT` | `target` |
